@@ -41,10 +41,17 @@ pub struct BatPrinter<'main> {
 
 impl<'main> BatPrinter<'main> {
     pub fn new() -> Self {
+        let styles = &[
+            StyleComponent::LineNumbers,
+            StyleComponent::Snip,
+            StyleComponent::Header,
+            StyleComponent::Grid,
+        ];
         let config = Config {
             colored_output: true,
             true_color: true,
             term_width: Term::stdout().size().1 as usize,
+            style_components: StyleComponents::new(styles),
             ..Default::default()
         };
         Self {
@@ -62,8 +69,13 @@ impl<'main> BatPrinter<'main> {
         self.config.theme = theme.to_string();
     }
 
-    pub fn grid(&mut self, enabled: bool) {
-        self.grid = enabled;
+    pub fn no_grid(&mut self) {
+        self.grid = false;
+        self.config.style_components.0.remove(&StyleComponent::Grid);
+    }
+
+    pub fn themes(&self) -> impl Iterator<Item = &str> {
+        self.assets.themes()
     }
 }
 
@@ -75,7 +87,7 @@ impl<'a> Printer for BatPrinter<'a> {
 
         // XXX: We don't use `bat::PrettyPrinter`.
         //
-        // `bat::PrettyPrinter` is an API exposed by bat and intended to be used by other Rust prgoram.
+        // `bat::PrettyPrinter` is an API exposed by bat and intended to be used by other Rust programs.
         // However this does not fit to hgrep implementation.
         //
         // 1. `bat::PrettyPrinter` cannot be shared across threads even if it is guarded with `Mutex<T>`
@@ -86,20 +98,12 @@ impl<'a> Printer for BatPrinter<'a> {
         //    at once. But it does not provide a way to specify the highlighted lines per file. The same
         //    lines are highlighted in all files and it is not fit to hgrep use case.
         // 3. To avoid 1. and 2., we created `bat::PrettyPrinter` instance per `BatPrinter::print()` call.
-        //    It worked but is very slow. It is 3.3x slower than current implementation. See commit
-        //    8655b801b40f8b3f7d4d343cae185604fa918d5b for more details.
+        //    It worked but was very slow since it loaded syntax highlighting assets each time. It was
+        //    3.3x slower than current implementation. See commit 8655b801b40f8b3f7d4d343cae185604fa918d5b
+        //    for more details.
 
         let mut config = self.config.clone();
 
-        let mut styles = Vec::with_capacity(4);
-        styles.push(StyleComponent::LineNumbers);
-        styles.push(StyleComponent::Snip);
-        styles.push(StyleComponent::Header);
-        if self.grid {
-            styles.push(StyleComponent::Grid);
-        }
-        config.style_components = StyleComponents::new(&styles);
-
         let ranges = file
             .chunks
             .iter()
@@ -123,7 +127,7 @@ impl<'a> Printer for BatPrinter<'a> {
 
         let controller = Controller::new(&config, &self.assets);
         // Note: controller.run() returns true when no error
-        // XXX: bat's Error type cannot be converted to anyhow::Error due to lack of some type bounds
+        // XXX: bat's Error type cannot be converted to anyhow::Error since it does not implement Sync
         match controller.run(vec![input]) {
             Ok(true) => Ok(()),
             Ok(false) => Err(Error::new(PrintError {
@@ -137,3 +141,42 @@ impl<'a> Printer for BatPrinter<'a> {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    fn sample_file() -> File {
+        let path = PathBuf::from("test.rs");
+        let lnums = vec![1];
+        let chunks = vec![(1, 2)];
+        let contents = "fn main() {\n    println!(\"hello\");\n}\n"
+            .as_bytes()
+            .to_vec();
+        File::new(path, lnums, chunks, contents)
+    }
+
+    #[test]
+    fn test_print_default() {
+        let p = BatPrinter::new();
+        let f = sample_file();
+        p.print(f).unwrap();
+    }
+
+    #[test]
+    fn test_print_with_flags() {
+        let mut p = BatPrinter::new();
+        p.tab_width(2);
+        p.theme("Nord");
+        p.no_grid();
+        let f = sample_file();
+        p.print(f).unwrap();
+    }
+
+    #[test]
+    fn test_print_nothing() {
+        let p = BatPrinter::new();
+        let f = File::new(PathBuf::from("x.txt"), vec![], vec![], vec![]);
+        p.print(f).unwrap();
+    }
+}
